package model

import (
	"fmt"

	pasturePb "gitee.com/xuyiping_admin/go_proto/proto/go/backend/cow"
)

type ImmunizationPlan struct {
	Id            int64                                 `json:"id"`
	Name          string                                `json:"name"`
	CowType       pasturePb.ImmunizationCowType_Kind    `json:"cow_type"`
	Conditions    pasturePb.ImmunizationConditions_Kind `json:"conditions"`
	Value         int64                                 `json:"value"`
	Value2        int64                                 `json:"value2"`
	IsShow        pasturePb.IsShow_Kind                 `json:"is_show"`
	OperationId   int64                                 `json:"operation_id"`
	OperationName string                                `json:"operation_name"`
	CreatedAt     int64                                 `json:"created_at"`
	UpdatedAt     int64                                 `json:"updated_at"`
}

func (i *ImmunizationPlan) TableName() string {
	return "immunization_plan"
}

func NewImmunizationPlan(systemUser *SystemUser, req *pasturePb.ImmunizationRequest) *ImmunizationPlan {
	return &ImmunizationPlan{
		Name:          req.Name,
		CowType:       req.CowType,
		Conditions:    req.Conditions,
		Value:         int64(req.Value),
		Value2:        int64(req.Value2),
		IsShow:        req.IsShow,
		OperationId:   systemUser.Id,
		OperationName: systemUser.Name,
	}
}

type ImmunizationPlanSlice []*ImmunizationPlan

func (i ImmunizationPlanSlice) ToPB(cowTypeOptions []*pasturePb.ConfigOptionsList, conditionsOptions []*pasturePb.ConfigOptionsList) []*pasturePb.ImmunizationRequest {
	res := make([]*pasturePb.ImmunizationRequest, len(i))
	for d, v := range i {
		cowTypeName, conditionsName := "", ""
		for _, c := range cowTypeOptions {
			if c.Value != int32(v.CowType) {
				continue
			}
			cowTypeName = c.Label
		}
		for _, cd := range conditionsOptions {
			if cd.Value != int32(v.Conditions) {
				continue
			}
			conditionsName = cd.Label
		}
		res[d] = &pasturePb.ImmunizationRequest{
			Id:             int32(v.Id),
			Name:           v.Name,
			CowType:        v.CowType,
			CowTypeName:    cowTypeName,
			Conditions:     v.Conditions,
			ConditionsName: conditionsName,
			Value:          int32(v.Value),
			IsShow:         v.IsShow,
			OperationId:    int32(v.OperationId),
			OperationName:  v.OperationName,
			CreatedAt:      int32(v.CreatedAt),
			UpdatedAt:      int32(v.UpdatedAt),
			Value2:         int32(v.Value2),
			DaysRange:      fmt.Sprintf("%d ~ %d", v.Value, v.Value2),
		}
	}
	return res
}
